select_sign_features.RdThe output of this function can be passed in the features argument of the h_map function
select_sign_features(
mRList = NULL,
test_method = "anova",
test_value = "q",
cutoff_value = Inf,
feature_id = "Feature_ID",
values = FALSE,
split_by_semicolon = FALSE
)mRList object
the name of the statistical test table contained in the mRlist object
the column of the statistical test table to consider (e.g.: p or q)
the value of p-value cut-off to consider a feature as significant
"Feature_ID", "Name" or "PubChemCID"; "Name" or "PubChemCID" require metabolite annotation
if TRUE a named vector with test_value values will be given in output; the beast value will be considered in case of 1-to-n mappings
if TRUE, the names will be split by semicolons.
a character vector with features names